@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2004 Bill Wilson
+|  Copyright (C) 1999-2005 Bill Wilson
 |
 |  Author:  Bill Wilson    bill@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -1465,7 +1465,9 @@ static GtkWidget
 				*ejectable_button,
 				*device_entry,
 				*secondary_button,
-				*show_button;
+				*show_button,
+				*delete_button,
+				*new_apply_button;
 
 static GtkWidget	*alert_button;
 
@@ -1784,6 +1786,8 @@ cb_tree_selection_changed(GtkTreeSelection *selection, gpointer data)
 	if (!gtk_tree_selection_get_selected(selection, &model, &iter))
 		{
 		reset_entries(FALSE);
+		gtk_button_set_label(GTK_BUTTON(new_apply_button), GTK_STOCK_NEW);
+		gtk_widget_set_sensitive(delete_button, FALSE);
 		gtk_widget_set_sensitive(alert_button, FALSE);
 		return;
 		}
@@ -1800,10 +1804,15 @@ cb_tree_selection_changed(GtkTreeSelection *selection, gpointer data)
 	if (depth == 1)
 		{
 		reset_entries(secondary);
+		gtk_button_set_label(GTK_BUTTON(new_apply_button), GTK_STOCK_NEW);
+		gtk_widget_set_sensitive(delete_button, FALSE);
 		gtk_widget_set_sensitive(alert_button, FALSE);
 		return;
 		}
+	gtk_button_set_label(GTK_BUTTON(new_apply_button), GTK_STOCK_APPLY);
+	gtk_widget_set_sensitive(delete_button, TRUE);
 	gtk_widget_set_sensitive(alert_button, TRUE);
+
 	fs = fs_new_from_model(model, &iter);
 	if (!secondary)
 		fs->show_if_mounted = FALSE;	/* in case dragged secondary->primary*/
@@ -1917,7 +1926,7 @@ N_("At least one primary fs monitor must exist to click on in order to show\n"
 	}
 
 static void
-cb_add(GtkWidget *widget)
+add_cb(GtkWidget *widget)
 	{
 	GtkTreeModel	*model;
 	GtkTreePath		*path = NULL;
@@ -2164,7 +2173,6 @@ create_fs_panels_page(GtkWidget *vbox)
 	GtkWidget				*table;
 	GtkWidget				*hbox, *hbox1, *vbox1;
 	GtkWidget				*label;
-	GtkWidget				*button;
 	GtkWidget				*scrolled;
 	GtkTreeModel			*model;
 	GtkCellRenderer			*renderer;
@@ -2271,13 +2279,14 @@ create_fs_panels_page(GtkWidget *vbox)
 	vbox1 = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_end(GTK_BOX(hbox), vbox1, FALSE, FALSE, 5);
 
-	gkrellm_gtk_button_connected(vbox1, &button, FALSE, FALSE, 4,
-			cb_add, NULL, GTK_STOCK_ADD);
-	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
-	gtk_widget_grab_default(button);
+	gkrellm_gtk_button_connected(vbox1, &new_apply_button, FALSE, FALSE, 4,
+			add_cb, NULL, GTK_STOCK_NEW);
+	GTK_WIDGET_SET_FLAGS(new_apply_button, GTK_CAN_DEFAULT);
+	gtk_widget_grab_default(new_apply_button);
 
-	gkrellm_gtk_button_connected(vbox1, NULL, FALSE, FALSE, 4,
+	gkrellm_gtk_button_connected(vbox1, &delete_button, FALSE, FALSE, 4,
 			cb_delete, NULL, GTK_STOCK_DELETE);
+	gtk_widget_set_sensitive(delete_button, FALSE);
 
 	gkrellm_gtk_alert_button(vbox1, &alert_button, FALSE, FALSE, 4, FALSE,
 			cb_set_alert, NULL);
