@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2004 Bill Wilson
+|  Copyright (C) 1999-2005 Bill Wilson
 |
 |  Author:  Bill Wilson    bill@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -355,7 +355,7 @@ gkrellm_sys_disk_read_data(void)
 		     ndevs * sizeof(long)) == ndevs * sizeof(long))
 		{
 		for (dn = 0; dn < ndevs; ++dn)
-			gkrellm_disk_assign_data_nth(dn, 0, cur_dk_xfer[dn]);
+			gkrellm_disk_assign_data_nth(dn, 0, cur_dk_xfer[dn], FALSE);
 		}
 	free(cur_dk_xfer);
 	}
@@ -422,7 +422,7 @@ gkrellm_sys_disk_read_data(void)
 			snprintf(name, sizeof(name), "%s%d", dev->device_name,
 					dev->unit_number);
 			gkrellm_disk_assign_data_by_name(name,
-					dev->bytes_read, dev->bytes_written);
+					dev->bytes_read, dev->bytes_written, FALSE);
 			}
 		free(dev_select);
 		}
